@@ -5,11 +5,12 @@ package Media::DateTime::JPEG;
 use strict;
 use warnings;
 
-our $VERSION = '0.48';
+our $VERSION = '0.49';
 
 use Carp;
 use Image::ExifTool;
 use DateTime;
+use Scalar::Util 'blessed';
 use Try::Tiny;
 
 my $exifTool;
@@ -57,7 +58,7 @@ sub datetime {
         );
     }
     catch {
-        if (/to DateTime::new did not pass/) {
+        if ((blessed $_ && $_->isa('Specio::Exception')) || /to DateTime::new did not pass/) {
             warn
               "JPEG's DateTimeOriginal exif entry ($f) not a valid datetime.\n"
               . "Fallback to file timestamp.\n";
@@ -89,7 +90,7 @@ Media::DateTime::JPEG - A plugin for the C<Media::DateTime> module to support JP
 
 =head1 VERSION
 
-version 0.48
+version 0.49
 
 =head1 SYNOPSIS
 
@@ -124,11 +125,11 @@ might check that exif data exists in the C<match> method.
 
 =head1 AUTHOR
 
-unknown
+Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by unknown.
+This software is copyright (c) 2016 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
